Smithsonian American Women's History Museum
Description: Womens History Homepage

Skip to main content

## Women's History Is
American History

# Womens History Homepage

learn more about Becoming Visible
Becoming Visible
Bringing American Women’s History into Focus
March 8, 2024 - Indefinitely

We know women have been making history for centuries but their stories are missing from the world around us. Explore five women's stories showcasing how that happens and learn what you can do to change it.

Enter Digital Exhibition about Becoming Visible

## News & Highlights

learn more about Dr. Mary Edwards Walker Recognized on New U.S. Quarter
Dr. Mary Edwards Walker Recognized on New U.S. Quarter
June 4, 2024
Read More
learn more about Elizabeth C. Babcock Named Director of the Smithsonian American Women’s History Museum
Elizabeth C. Babcock Named Director of the Smithsonian American Women’s History Museum
March 12, 2024

Elizabeth C. Babcock has been named director of the Smithsonian American Women’s History Museum, effective June 3.

Read more about Elizabeth C. Babcock Named Director of the Smithsonian American Women’s History Museum

learn more about Dr. Marian Pettibone Discovered and Described New Forms of Oceanic Life
Dr. Marian Pettibone Discovered and Described New Forms of Oceanic Life
June 26, 2024
Read More

## Connect & Contribute

learn more about Share Your Story
Share Your Story
learn more about Support Our Work
Support Our Work
learn more about Get Involved
Get Involved
Back to Top